#
# spec file for package platformsh-cli
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           platformsh-cli
Version:        3.17.0
Release:        1.1
Summary:        Tool for managing Platform.sh services from the command line
# See licenses.txt for dependency licenses.
License:        MIT
Group:          Productivity/Networking/Web/Servers
Url:            https://github.com/platformsh/platformsh-cli
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-vendor.tar.xz
Source10:       extensions.php
Source11:       extensions.txt
Source12:       licenses.txt
Source13:       update.sh
BuildRequires:  xz
Requires:       php >= 5.5.9
Suggests:       php-curl
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
The Platform.sh CLI is the official command-line interface for Platform.sh.
Use this tool to interact with Platform.sh projects, and to build them
locally for development purposes.

%prep
# -a 1: unpack Source1 vendor tarball
%setup -q -a 1

%build
find . -name ".travis.yml" -delete

%install
# install drush source
install -d -m 0755 . %{buildroot}%{_datadir}/%{name}
cp -r * %{buildroot}%{_datadir}/%{name}

# link to executable in bindir
mkdir -p %{buildroot}%{_bindir}
ln -s %{_datadir}/%{name}/bin/platform %{buildroot}%{_bindir}/platform

# link to bash complete script
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
ln -s %{_datadir}/%{name}/shell-config.rc %{buildroot}%{_sysconfdir}/bash_completion.d/platform.sh.complete.sh

%files
%defattr(-,root,root,-)
%{_datadir}/%{name}
%{_bindir}/platform
%{_sysconfdir}/bash_completion.d/platform.sh.complete.sh

%changelog
* Tue May 30 2017 jimmy@boombatower.com
- Update to version 3.17.0:
  * Update console-form dependency
  * Docs search now needs rawurlencode()
  * Improve default Drush aliases on cloning (#603)
  * Add environment:init command
  * Release v3.17.0
* Fri May 19 2017 jimmy@boombatower.com
- Update to version 3.16.2:
  * Note how to run the CLI from source
  * Note how to run the CLI from source
  * Correct comment in ProjectGetCommand
  * Fix: certificate:delete command missing --no-wait option
  * Add --blobs to pg_dump
  * Installer: ignore errors in source/dot command in shell config
  * Better English in installer
  * Release v3.16.2
* Mon May 15 2017 jimmy@boombatower.com
- Update to version 3.16.1:
  * When creating a symlink, ensure both ends are real paths, if possible
  * Use improved makePathRelative elsewhere
  * Unused import
  * Use improved makePathRelative() in get command
  * ... typo
  * Release v3.16.1
* Thu May 11 2017 jengelh@inai.de
- Kill dot off summary. Fix other nonsense in description.
* Wed May 10 2017 jimmy@boombatower.com
- Update to version 3.16.0:
  * Remove old updates.last_checked default
  * Remove application.phar config value
  * Update self::install so it doesn't write to .profile
  * Fix filename if a directory is passed to the db:dump --file option
  * Stop timestamp being appended twice if --file is a directory
  * Add --directory option to db:dump
  * Use native search in docs command
  * Simplify DocsCommand
  * Note config.yaml snippet shows defaults
  * Update API client
  * Use starts_at paging to load more than 10 activities
  * Update API client for activity descriptions
  * Add project:curl command
  * Add auth:token command
  * Add -sS to project:curl
  * Release v3.16.0
* Wed May  3 2017 jimmy@boombatower.com
- Update to version 3.15.4:
  * Save update check time (to a place other than config)
  * Note State could be used more often
  * Simplify State->save()
  * Release v3.15.4
* Mon May  1 2017 jimmy@boombatower.com
- Update to version 3.15.3:
  * Fix wrong array keys in certificate:add
  * Trigger patch in platformsh/client package to actually apply
  * Document PLATFORMSH_CLI_TOKEN variable, with a warning
  * Do not check for updates immediately after install
  * Since we have the filename, the Phar can run directly
  * No need to write to user config for updates check
  * Release v3.15.3
* Mon May  1 2017 jimmy@boombatower.com
- Update to version 3.15.2:
  * Explain that auto-provisioned certificates can't be deleted
  * Show issuer in certificate:list
  * Allow partial match on ID in certificate:delete
  * Use RequestTty only for certain commands, when stdin is a tty
  * Add --raw option to sql command
  * SSH commands need to show errors
  * Downgrade Process, avoiding apparent segfault
  * Ensure running another command doesn't wipe necessary service data
  * Release v3.15.2
* Wed Apr 26 2017 jimmy@boombatower.com
- Update to version 3.15.1:
  * Add more contextual help in activity:list
  * Avoid formatting activity result in CSV/TSV output
  * Use pseudo-terminal for SSH
  * Remove CommandBase->isTerminal() in favour of Output->isDecorated()
  * Remove unnecessary 2>&1 from sql/drush over SSH commands
  * Use RequestTty and remove LogLevel hack
  * Update dependencies
  * ... security-checker still doesn't work via PHP in Travis
  * Rely on date_default_timezone_get() instead of UTC fallback
  * Update comment
  * Ssh issue with windows (#592)
  * Add certificate commands (#583)
  * Fix return value in certificate:add
  * Release v3.15.0
  * Fix certificate:delete confirm question
  * Release v3.15.1
* Mon Apr 17 2017 jimmy@boombatower.com
- Update to version 3.14.5:
  * Fix wrong QuestionHelper argument in "get" command
  * Remove two other non-type-hinted uses of getService()
  * Use ConsoleOutputInterface for stderr feature detection
  * Ensure target is realpath in symlink()
  * Release v3.14.5
* Sun Apr 16 2017 jimmy@boombatower.com
- Update to version 3.14.4:
  * Further improved timeout in project:create (blocking)
  * Move orphan logic up into buildEnvironmentTree
  * List 10 activities by default
  * More info with verbose output for a successful db:dump
  * Issue #585: Don't add bashisms to .profile
  * Make available plans/regions configurable
  * Fix URL opening on OS X (#586)
  * Release v3.14.4
* Wed Apr  5 2017 jimmy@boombatower.com
- Update to version 3.14.3:
  * Fix: existing file preventing file mount symlink
  * Run security check via curl in Travis for now
  * Avoid setting the upstream on the wrong branch
  * Further solidify setting an upstream for the right branch
  * Show if a snapshot failed in snapshot:list
  * Filter by successful snapshots in snapshot:restore
  * Display result (success/failure) for all activities
  * Improve timeout logic in project:create
  * Examples property can be private
  * Revert symfony/console to 3.2.4 to fix input validation
  * Release v3.14.3
* Wed Mar 29 2017 jimmy@boombatower.com
- Update to version 3.14.2:
  * Update dependencies
  * Remove "toolstack" concept, use "flavor"
  * Relative paths should not depend on files already existing
  * Remove makePathRelative() method (use Symfony directly)
  * Exception if query fails in db:size
  * Expose error output properly in db:size queries
  * Fix imports
  * Simplify error control; stop displaying two exceptions on bad connection
  * Release v3.14.1
  * Downgrade Process component to fix env var bug
  * Fail hard if the home directory is not found or valid
  * Release v3.14.2
* Wed Mar  1 2017 jimmy@boombatower.com
- Update to version 3.14.0:
  * Cache an empty relationships list
  * Add route-get command to view a resolved route to an environment
  * Rename route commands
  * Clarify URL choice in `url` command
  * Refactor code that reads remote environment variables
  * Fix cache clearing for env vars
  * Improve RemoteEnvVars documentation
  * Remove odd relationships dependency on @output
  * Fix integration option names
  * Release v3.14.0
* Thu Feb 23 2017 jimmy@boombatower.com
- Update to version 3.13.0:
  * Drupal settings: remind user to uncomment database config block
  * Update dependencies
  * Install build-time dependencies
  * Allow numerals in region domain components
  * Cleanup
  * Add an option to install dependencies globally
  * Remove yarn; fix npm install
  * Remove global deps for now, and downgrade missing package manager to a warning
  * Fix and test usage of PYTHONPATH
  * Add commands to run the PHP built-in web server
  * Update for CLI 3.x
  * Server: support custom variables prefixes
  * Locations (WIP)
  * Remove blank lines from log in server:start
  * Enable server commands via a feature flag
  * Update for new DIC
  * Implement static files rules and 'scripts' check
  * Refactor dead process check
  * Fix Drupal workaround
  * Open URLs for server:start
  * Fix APP_DIR setting
  * Incorporate routes
  * Use API client for project estimate
  * Update to Symfony 3.2.4
  * Release v3.13.0
* Wed Feb  8 2017 jimmy@boombatower.com
- Update to version 3.12.2:
  * Return failure code in activate command if the activity fails
  * Release v3.12.2
* Thu Feb  2 2017 jimmy@boombatower.com
- Update to version 3.12.1:
  * Comment mentions old method
  * More specific gitignore for Drupal vanilla
  * Allow updates.check to be overridden by an env var
  * Allow web command to be used with a non-existent environment
  * Improve 'get' when the user does not have access to master (#569)
  * Release v3.12.1
* Sat Jan 21 2017 jimmy@boombatower.com
- Update to version 3.12.0:
  * db:dump: add --bzip2 option
  * Tweaks
  * ...ok, no need for bzip2
  * Fix installer typo
  * Avoid $user as var name
  * Wrong comment
  * Use --no-color with git branch
  * Protect getVersion() methods
  * phpcs fixes
  * I believe there are missing double quotes there. (#561)
  * I believe there are missing double quotes there. (#561) (cherry-pick)
  * Add explicit platform.sh CLI name to SelfUpdater output  messages.
  * Add project:set-remote command
  * Update client
  * Stop enforcing an "origin" remote
  * Use the configurable application name
  * Add project variable commands to README
  * Installer: more precise shell config files preferences (#565)
  * master version has moved
  * Fix using integration:get command without an argument, when none exist
  * Set upstream in 'branch' only if the correct branch is checked out
  * Fix title in branch command
  * Clarify checkout command when creating new branch
  * Release v3.12.0
* Tue Jan 10 2017 jimmy@boombatower.com
- Update to version 3.11.0:
  * Offer to autocomplete the project ID for the directory in `platform get`
  * Use getEnvironment() in platform get, for consistency
  * ... and use the real environment ID
  * Add PropertyFormatter::displayData()
  * Test on 7.1
  * Refactor ProjectGetCommand
  * Expand possible site domains
  * Only show "Usage" after invalid input
  * Sensible error in self:build if phar.readonly is enabled
  * Document displayData() and tweak YAML formatting
  * Remove uses of deprecated getTerminalDimensions()
  * Allow extra regions to be used in create command
  * Allow debug/SSL config to be used with getEstimate()
  * Skip activate logic in push command if the target is master
  * Add --gzip option to db:dump
  * Account for hidden aliases in short command name
  * Hide a couple of aliases
  * Unify project option/argument syntax for project:delete and project:get
  * Remove uses of deprecated Completion::makeGlobalHandler()
  * Unused import
  * Refactor SQL connection options
  * Less repetition
  * environment:delete: Don't offer to delete the branch if --no-wait is specified
  * Fix pgsql arguments (--password doesn't allow a password value)
  * db:dump: add more advanced options
  * db:dump: warn if file is not excluded by Git
  * Release v3.11.0
* Wed Dec 28 2016 jimmy@boombatower.com
- Update to version 3.10.2:
  * Inject Git service for LocalProject
  * Push command: allow specifying the target branch
  * Disallow pushing an empty source
  * Verify source with Git
  * Show whether pushing to a new or existing env
  * Shell: use stdErr properly and make environment obvious in verbose output
  * Separate stdout/stderr in ProcessManager if possible
  * Satisfy Scrutinizer
  * Release v3.10.1
  * Set environment after running git --version
  * Pass on more options from push to activate command
  * ActivityMonitor: hide progress bar if output is not decorated (#556)
  * Ensure a fresh cache in getEnvironment() before determining nonexistence of an environment
  * Fix default service for `output`
  * Release v3.10.2
* Tue Dec 27 2016 jimmy@boombatower.com
- Update to version 3.10.0:
  * Add push command
  * Refactor custom SSH commands for Git and other uses
  * Refactor Util and Helper classes into a DIC with services
  * Attempt to ensure $_ENV and $_SERVER are populated
  * Update project:variable commands for DI
  * push command: fix extra space in Git args
  * push command: don't throw an exception if the Git command fails
  * push command: fix --force was not forwarded to git
  * Convert UrlCommandBase to Url service
  * push command: use git remote (helps for tracking)
  * Update client
  * Convert Api and cache factory to services
  * Rename CliConfig to Config service
  * Consistent interface for Table
  * Fix Filesystem arguments
  * Unnecessarily optional arguments
  * Tidy output verbosity in CommandBase
  * Convert LocalBuild to a service
  * push command: Clear environments cache on success
  * Avoid repeating an API request looking for a non-existent environment
  * Remove getHomeDir from CommandBase
  * Remove CommandBase->getSessionsDir()
  * Clear relationships cache after pushing
  * Private where possible (for now) in CommandBase
  * Restore Drush->setHomeDir() to fix tests
  * Fix Drush class for PHP <7
  * Add docblocks to all service objects
  * Fix URL openers
  * Use configureIO instead of doRun
  * Move ActivityUtil to ActivityMonitor service
  * Unused vars
  * Minor ActivityMonitor tidy
  * Clear up stderr/stdout confusion in Shell and Toolstack classes
  * Ignore SSH error after pushing
  * Rename Util -> NestedArrayUtil
  * Add test for NestedArrayUtil
  * Improve activation/parenting in push command
  * Clear environments cache after activation
  * Refactor activate-after-push
  * Fix static cache
  * Allow changing interactivity in runOtherCommand
  * Remove shebang hack for portability
  * Avoid offering to parent master
  * Remove uses of getProperty()
  * Push command: add -f, remove --dry-run
  * Show short name in examples
  * Add examples of push command
  * Release v3.10.0
* Wed Dec 14 2016 jimmy@boombatower.com
- Update to version v3.9.0:
  * multi: separate stderr and stdout
  * Make sql-dump not depend on a project root
  * Add --no-dev to composer/symfony build flavors
  * Revert "Add --no-dev to composer/symfony build flavors"
  * Flag suspended projects in the list
  * Warn about a suspended project in the welcome command.
  * Show login command for LoginRequiredException
  * Cache the list of log files
  * Release v3.8.1
  * Add a Project Variable Set command.
  * Add a Project Variable Delete command.
  * Add a Project Variable Get command.
  * Register the new Project Variable commands.
  * Exception if subscription not found
  * More generic log command autocomplete
  * Add unix shell as requirement (#545)
  * Clear the cache after a long-running activity
  * Ignore unreadable directories when searching for applications
  * Allow choosing a database via a --relationship command line option
  * Mention other build tools in README
  * Revert unnecessary RelationshipsUtil changes
  * Strip subdomains from project URLs
  * Update composer.json.
  * Release v3.9.0
- Take advantage of versionrewrite-pattern param for tar_scm to remove v prefix
  from tag to create a standard version that works better with tools.
  https://github.com/M0ses/obs-service-tar_scm/pull/1
* Thu Nov 10 2016 jimmy@boombatower.com
- Update to version v3.8.0:
  * Fix: environments url-encoded in parsed URL
  * Fixed broken environment:sql command on PostgreSQL databases. (#530)
  * Fix config for domain detection
  * Allow locating projects by ID only
  * Cache projects located by ID
  * Allow 'url' as a special property in info commands
  * Fix pldr/platform_local_drush in Bash
  * Consistent Bash quoting
  * Improve errors when no environment selected
  * Unused $message variable
  * Fix chooseDatabase() to not hardcode the relationship name
  * Create CLI command for quick-read on SQL disk usage.
  * Reduce the output to max space, used space and percent used.
  * sqls: Use Table class
  * No need to use BufferedOutput now
  * Coding standards (PSR-2 / Symfony)
  * Add help texts.
  * Find service name via relationship name in app config
  * Removed lines related to verbosity.
  * Prevent division by zero if allocated disk size could not be determined.
  * Prevent warnings when database service disk cannot be determined.
  * Add db namespace for database commands (#535)
  * Release v3.8.0
* Fri Nov  4 2016 jimmy@boombatower.com
- Update to version v3.7.1:
  * ... more specific check for Drush env var
  * Add a static cache for project config and remove indirection
  * auth:info command: property argument, and allow uuid as property
  * Ignore timeouts in project:create
  * Coding standards in ProjectCreateCommand
  * Ignore failure to download in delegated self-update
  * ... follow-up to actually ignore download failure
  * Permit a command to continue after updating (#529)
  * Release v3.7.1
* Thu Oct 27 2016 jimmy@boombatower.com
- Update to version v3.7.0:
  * Save a Git symbolic-ref command on most calls to getCurrentBranch()
  * Add --run-deploy-hooks option to build command
  * Harmonise build settings with build command options
  * Fix relevant build options for the tree id
  * Mini refactor
  * Do not back up a symlinked build directory
  * Test repeated Drupal build
  * Allow Drush location to be overridden for tests
  * Release v3.7.0
* Fri Oct 21 2016 jimmy@boombatower.com
- Update to version v3.6.0:
  * Write to .git/info/exclude more often
  * Default to NO for removing remote branch and add option to not delete
  * make sure local branch is tracking upstream on environment:branch
  * Setting the upstream after everything was created
  * Keep default to Y
  * Specify --inactive or --no-delete-branch, not both
  * Allow deleting merged and inactive envs in one command (#521)
  * Installer: avoid misleading error if $argv doesn't exist
  * Add --my filter to project:list
  * Cache the current user's account info
  * Move proc_open() logic into ShellHelper
  * Simpler output-if-verbose syntax
  * Installer: better fix for empty $argv notice
  * Show alias and executable name in command synopsis (i.e. "platform branch" instead of "environment:branch") (#526)
  * Expose current account info via auth:info command (#525)
  * Add a 'none' toolstack
  * Release v3.6.0
* Fri Oct  7 2016 jimmy@boombatower.com
- Update to version v3.5.4:
  * Additional fix for Drush and the profile directory
  * Only backup the build directory if it is a real dir
  * Release v3.5.4
* Fri Oct  7 2016 jimmy@boombatower.com
- Update to version v3.5.3:
  * Fix (again) environment URL in `web` command
  * Fix 'Remote branch  not found' regression in 'platform get' with no arguments
  * Release v3.5.3
* Thu Oct  6 2016 jimmy@boombatower.com
- Update to version v3.5.2:
  * Improve activities batch performance (#510)
  * Allow "get" command with a project URL (update for machine name)
  * Fix exception when SSH key is not found
  * Simpler check in doRun()
  * Ensure temporary directory does not exist before Drush make (#516)
  * Use starts_at in activity batching
  * Fix selectEnvironment() bug from 9049359cb2d18b57dc480578a8335e9b1dfa0144
  * Correct UI URL in 'web' command for envs with special characters
  * Release v3.5.1
  * Allow special characters in branch command
  * Improve formatting of API error details
  * Fix environment:info bug when updating the parent
  * Release v3.5.2
* Fri Sep 23 2016 jimmy@boombatower.com
- Update to version v3.5.0:
  * Add --exclude option to environment:delete
  * Remove dist/manifest.json
  * Rename to installer.php
  * Refactor environment:checkout a bit
  * Add 'title' filter to project:list (#505)
  * Add --no-backup option to build command (#504)
  * Provide an option to clone to the build directory (#475)
  * Refactor project title/id labels
  * Account for left-indented cells in adaptive table
  * .. only spaces for now
  * Add experimental plan size overrides (#508)
  * Recursively display orphaned environments (#507)
  * Simplify listProperties()
  * Update Symfony dependencies to 3.1.4
  * Release v3.5.0
* Sat Sep 10 2016 jimmy@boombatower.com
- Add source entries for files used to maintain package.
* Fri Aug 26 2016 jimmy@boombatower.com
- Update to version v3.4.1+git20160826.adf340f:
  * Update manifest for v3.4.0
  * Work around Unicode problem in branchExists()
  * Simplify branch name handling in checkout
  * Use strict in_array() for ideological correctness
  * Fix exporting a Drush alias for branch names containing '
  * Release v3.4.1
* Wed Aug 24 2016 jimmy@boombatower.com
- Update to version v3.4.0+git20160824.3d4baf5:
  * Copy install files into the repository
  * Installer: require phar, and warn about ctype
  * Add README.md to dist directory
  * Add --date-fmt option to info commands
  * Update Symfony and dev dependencies
  * Validate roles case insensitively in user:add
  * Select environments with unsanitized name first
  * Allow selecting the environment by machine_name
  * Add domain:update command
  * Add domain:get comand
  * Change default CSV/TSV and datetime formats
  * Add an interactive domain name choice
  * Simplify ssl.expires_on formatting
  * Release v3.4.0
* Wed Aug 10 2016 jimmy@boombatower.com
- Update to version v3.3.6+git20160809.d262f3f:
  * Avoid parseProjectId() on null
  * Added an editorconfig file to keep IDEs properly behaved.
  * Update dependencies. Should mitigate CVE-2016-5385 and allow PHP 7.1 support
  * Add security-checker in Travis (#482)
  * Use a direct proc_open() instead of passthru() (#484)
  * Remove extra parsing to find SSH/Drush commands (#485)
  * Release v3.3.5
  * Follow-up fix: SSH and Drush commands silently dropping arguments
  * Explicitly check the PHP version when running the CLI tool (#489)
  * Ensure the project ID is written to config after 'get'
  * Report progress during Git clone (#487)
  * No need anymore for temporary vars in the executable file
  * More reliably exclude .platform/local from Git
  * Use a separate session ID for API tokens (#492)
  * Release v3.3.6
* Fri Jul  8 2016 jimmy@boombatower.com
- Update to version v3.3.4+git20160708.06057ca:
  * Account for environments without $_ENV when loading config
  * Unused variable
  * Provide configured executable name to help instead of PHP_SELF
  * Ignore the blank lines from drush --version output
  * Fix undefined function in integration:update (issue #465)
  * Output simple table when there is no format option e.g. after integration:update
  * Release v3.2.2
  * Remove minimum Drush version check (#464)
  * Tweak to integration code style for more flexibility
  * Display fatal runtime errors by default.
  * Hide clean command; unhide dir command
  * Symlink all mounts, from the build to shared directories (#470)
  * Use chmod to force deleting builds even when files are read-only (#469)
  * Fix: --copy option caused dot files to be copied
  * Add regression test for copyAll() expanding the blacklist via fnmatch()
  * Create a settings.local.php for Drupal + Composer (#471)
  * Yaml::parse() lies about its return value being an array
  * Allow the API token to be set via a file specified in ~/.platformsh/config.yaml (#472)
  * Release v3.3.0
  * Prevent new lines messing up tokens
  * Show roles on all environments in user:role
  * Add autocompletion and other improvements for user:role
  * Fix overriding a config array with a scalar value
  * More user:role tidying
  * More efficient unprotect()
  * Docblock for Table class
  * Fix apparent bug in getProjectRoot() with legacy project structures
  * Remove vfsStream and clean up temp test dirs
  * Document user config overrides in config.yaml
  * Allow overwriting files with shared file mount symlinks
  * Use --recursive option to git clone
  * Revert "Use --recursive option to git clone" (only introduced in Git 1.6.5)
  * Make the level more obvious in user:role
  * Clean up LocalBuild settings
  * Pass verbosity on to Composer
  * Release v3.3.1
  * Report more error detail for DELETE requests
  * Suppress usage for welcome command errors
  * Correct service name for project:get with empty repo
  * Account for orphaned environments in environment:list
  * Unused import
  * Release v3.3.2
  * Fix environments duplicated in list (caused by 3b2d61238347b2cc1c614af9ca10cec902908d0d)
  * Release v3.3.3
  * Update client to fix reporting all empty responses as failure (even 200)
  * Assume Drush is installed if the command resolved (#478)
  * Release v3.3.4
* Mon Jun 13 2016 jimmy@boombatower.com
- Update to version v3.2.1+git20160613.816de17:
  * Ensure old build is removed properly
  * Tidy weird foreach() in ProcessManager
  * Improve environment:delete --merged
  * Use 'git checkout --track' in checkout command
  * GitHelper docs/test cleanup
  * Add PHP version information to the User-Agent
  * Release v3.1.2
  * Update default Drupal settings (#458)
  * Sort projects and environments (#459)
  * Add 'platform multi' command
  * Fix ArgvHelper issue when running with multi (for ssh/drush)
  * Fix doRunCommand() signature
  * Fix whether an environment is required in activity:list
  * Various sortResources() fixes
  * Allow sorting by a nested property
  * Disable some command combinations via multi
  * Git exclude info not added for empty projects
  * Always refresh environments in the 'welcome' command
  * Allow certain config to be overridden by the user
  * Add project:create command
  * Use static cache for project root when it is not found.
  * Better naming and remove NULL for $keyExists
  * ... just testing
  * Only remove the previous build when the new one completes
  * Allow the update check interval to be overridden
  * Unhide multi; remove -c alias
  * Release v3.2.0
  * Fix 'multi' command in configurations without $_ENV superglobal
  * So now $env is not needed.
  * Release v3.2.1
* Wed Jun  1 2016 jimmy@boombatower.com
- Update to version v3.1.1+git20160530.705c22c:
  + Fix drush issue (#185)
  + Fix bug in getEnvironment() (#188)
  + A further fix for getEnvironment().
  + Use HOME system variable inside double quoted PATH export
  + Call Drush with the full path to avoid a drush.bat issue on Windows.
  + Fix tar paths for Windows.
  + Fix infinite loop in getProjectRoot()
  + Hot fix - vanilla builds broken by archive behaviour
  + Follow SSH key generation with ssh-add.
  + Fix exit codes for branch
  + Hotfix: undefined variable $projectRoot
  + Temporarily remove Phar installation instructions
  + Show tunnel commands in the list; check support at 'runtime'
  + Show integration:get in the command list
  + Fix autocompletion errors
  + Fix some Scrutinizer issues
  + Remove some dead code
* Fri Mar 25 2016 jimmy@boombatower.com
- Update to 3.0.7.
* Thu Mar 24 2016 jimmy@boombatower.com
- Update to 3.0.4.
* Wed Mar 23 2016 jimmy@boombatower.com
- Update to 3.0.2.
* Tue Mar 22 2016 jimmy@boombatower.com
- Update to 3.0.0.
* Sun Mar 13 2016 jimmy@boombatower.com
- Update to 2.13.2.
- Split vendor directory instead separate tarball to allow for
  source verification.
* Wed Mar  9 2016 jimmy@boombatower.com
- Update to 2.13.1.
- Update installation of rc file for upstream renaming.
* Mon Feb 29 2016 jimmy@boombatower.com
- Update to 2.13.0.
* Wed Feb 17 2016 jimmy@boombatower.com
- Update to 2.12.3.
* Fri Feb 12 2016 jimmy@boombatower.com
- Correct liscenses.txt spelling.
- Simplify find command with -delete flag.
* Fri Feb 12 2016 jimmy@boombatower.com
- Update to 2.12.1.
* Thu Feb 11 2016 jimmy@boombatower.com
- Initial import of 2.12.0.
